@@ -1,7 +1,7 @@
 try:
     from django.conf.urls import patterns, include
 except:
-    from django.conf.urls.defaults import patterns, include
+    from django.conf.urls.defaults import patterns, include, handler404
 
 from django.contrib import admin
 admin.autodiscover()
